#ifndef _HUBWDGT_H_
#define _HUBWDGT_H_

#include <qlineedit.h>
#include <qtextedit.h>

#include "userlist.h"
#include "userfiledlg.h"

#include <list>

class dctc_hub;
class dc_hub;
class TransferDlg;
class QPushButton;
class QTabWidget;
class ChatWdgt;
class SearchDlg;

using namespace std;

/*!
\class HubWdgt
\breif Provides functions for a hub connection and displays information about it

This class is used for every hub we are connected to. 
It has a line edit and search button for performing searches, a button for 
disconnecting from the hub. It also has two tabs, one in which the chat 
messages are displayed and one in which all users are displayed along 
with that users information.
*/

class HubWdgt : public QWidget
{

     Q_OBJECT

public:
     /*!
       Constructor that creates all the widgets needed and connects to the 
       hub adress we get

       \param transferWin The transfer lists
       \param parent The parent widget.
       \param name The name of this widget.
     */
     HubWdgt( TransferDlg* transferWin, QWidget* parent = 0, const char* name = 0 );

     /*!
       Sets the id of this hub tab. Has ro be done after the hub is created
       and added to the tabs in our main widget otherwise this willl get
       fucked when this tab is closed.

       \param hubId The id to be set
     */
     void setId( int hubId ) { id = hubId; }

     /*!
       Returns true if the the hubwidget is connected.
     */
     bool isConnected() { return hubInterface!=NULL; }

     bool connect();     

public slots:

     void handleSearchResult(const QString &user,
				 const QString &file,
				 const QString &size,
				 const QString &slot,
			     const QString &hubname);

     /*!
       Slot for disconnecting from this hub
     */
     void disconnect();

     /*!
       Adds a user to the user list
       
       \param nick The nick of the new user
       \param share The size of the users shared files
       \param con The connection type the user has
       \param desc The user description
     */
     void addUser( const QString& nick, const QString& share, const QString& con, const QString& desc ){}
     
     /*!
       Removes a user from the user list
       
       \param nick The nick of the user to be removed
     */
     void removeUser( const QString& nick ){}

     void activateChat(const QString& user);
     void privChatMsg(const QString& user, const QString& msg);
     void sendChatMes(const QString& msg,QWidget* originator);
     void setHubName(const QString& name);

     void removeFileDlg( const QString& user );

     void loadUserList( const QString& user );

     void openSearchDlg();

    void queryUnattached(const QString& name);
    void requestPassword();
signals:
     void gotName(const QString&,QWidget*);
    void multiSearchResult(const QString&,const QString&,const QString&,const QString&,const QString&);
    void disconnected(int);
private:
     /*!
       Displys the users connected to this hub
     */
     UserList* users; // Should be a listview
     
     /*!
       The id of this hub. We get this from the widget that
       created us.
     */
     int id;

     /*!
       The dctc_hub object that is the interface for communicating
       with dctc.
     */
     dctc_hub *hubInterface;

     dc_hub *hubs;

     /*!
       The transfer lists
     */
     TransferDlg *transferWin;

     /*!
       The public chat
     */
     ChatWdgt *publicChat;

     QTabWidget* tabs;

     /// The hub name
     QString name;

     SearchDlg* searchDlg;

     list<UserFileDlg *> dialogs;
};

#endif

/*
 *
 * $Log:
 *
 */
